/***************************************************************************
 *   Copyright (C) 2006 by Alexandru Olaru                                 *
 *   qumbetlian@yahoo.com                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef QDIALOG_HH
#define QDIALOG_HH

#include <errno.h>
#include <gtkmm/dialog.h>
#include <gtkmm/button.h>
#include <gtkmm/buttonbox.h>
#include <gtkmm/label.h>
#include <gtkmm/box.h>

#define YES 1
#define NO 0

class qdialog : public Gtk::Dialog
{

		class Gtk::Dialog *qdialog1;
		class Gtk::Button *button_yes;
		class Gtk::Button *button_no;
		class Gtk::Label *question_label;
	public:
		qdialog(Gtk::Window& parent, const char* title, const char* message, const char* default_button = "yes");
		~qdialog(){
                   };
		void on_yes_clicked(void);
		void on_no_clicked(void);
};
#endif
